… | OiRA

Help

1. Paruošimas
2. Įtraukti
3. Nustatymas + Vertinimas
   1. 1 Commercial manned guarding
   2. Ω Jūsų įtrauktos rizikos
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Neatsakyta
   - Atidėta
   - GERAI
   - Dėmesio
4. Veiksmų planas
5. Ataskaita
6. Būsena 0%

## Aprašykite riziką…

Ar rizika priimtina? Ne, būtinos papildomos priemonės Taip, likusi rizika yra priimtina

Select the priority of this risk Low Medium High
Informacija
Įkelti paveikslėlįlabel_upload_image
Komentarai

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More